<?php

namespace App\Controllers;

use PDO;
use PDOException;
use InvalidArgumentException;
use Longman\TelegramBot\DB;
use Longman\TelegramBot\TelegramLog;

class OfferController
{
    private $db;
    private $category;
    private $place;
    private $offerId;
    private $offerCategories = [
        'credits',
        'sales',
        'promocodes',
        // 'insurances',
    ];
    private $scrapLinks = [
        'atb' => 'https://www.atbmarket.com/promo/all', // Пример ссылки для парсинга
    ];

    public function __construct($category, $place = null, $offerId = null)
    {
        $this->config   = require __DIR__ . '/../../config.php';
        $this->db       = DB::getPdo();

        if (!in_array($category, $this->offerCategories, true)) {
            throw new InvalidArgumentException('Invalid category specified');
        }

        $this->category = $category;
        $this->place    = $place;
        $this->offerId  = $offerId;
    }

    public function getOffers()
    {
        $tableName = 'offer_' . $this->category;

        $params = [];
        $sql = "SELECT DISTINCT ";

        if (($this->category === 'sales' || $this->category === 'promocodes') && $this->place === null && $this->offerId === null) {
            $sql .= "place ";
        } else {
            $sql .= "* ";
        }

        $sql .= "FROM $tableName";

        if ($this->place !== null) {
            $sql .= " WHERE place = :place";
            $params['place'] = $this->place;
        }

        if ($this->offerId !== null) {
            $sql .= isset($params['place']) ? " AND id = :offerId" : " WHERE id = :offerId";
            $params['offerId'] = $this->offerId;
        }

        if ($this->place !== null) {
            $sql .= " ORDER BY end_date ASC";
        }

        try {
            $stmt = $this->db->prepare($sql);
            $stmt->execute($params);
            return $stmt->fetchAll(PDO::FETCH_ASSOC);

        } catch (PDOException $e) {
            TelegramLog::error('Failed to fetch offers: ' . $e->getMessage());
            return [];
        }
    }

    public function scrapOffers($place)
    {
        return;
    }
}